@@ -53,6 +53,7 @@ struct analyze_context_s
 	Patch_element patch_array[MAX_LINKS];
 };
 
+#ifdef USE_FAT_LINKAGES
 typedef struct CON_node_struct CON_node;
 typedef struct CON_list_struct CON_list;
 typedef struct DIS_list_struct DIS_list;
@@ -91,6 +92,7 @@ struct Links_to_patch_struct
 	char dir;   /* this is 'r' or 'l' depending on which end of the link
 				      is to be patched. */
 };
+#endif /* USE_FAT_LINKAGES */
 
 void zero_sublinkage(Sublinkage *s)
 {
@@ -115,26 +117,35 @@ static Sublinkage * x_create_sublinkage(Parse_info pi)
 	return s;
 }
 
-static Sublinkage * ex_create_sublinkage(Parse_info pi)
+static void ex_init_sublinkage(Parse_info pi, Sublinkage *s)
 {
-	Sublinkage *s = (Sublinkage *) exalloc (sizeof(Sublinkage));
 	s->link = (Link **) exalloc(pi->N_links*sizeof(Link *));
 	s->num_links = pi->N_links;
 
 	zero_sublinkage(s);
 
 	assert(pi->N_links < MAX_LINKS, "Too many links");
+}
+
+#ifdef USE_FAT_LINKAGES
+static Sublinkage * ex_create_sublinkage(Parse_info pi)
+{
+	Sublinkage *s = (Sublinkage *) exalloc (sizeof(Sublinkage));
+	ex_init_sublinkage(pi, s);
 	return s;
 }
+#endif /* USE_FAT_LINKAGES */
 
 static void free_sublinkage(Sublinkage *s)
 {
 	int i;
-	for (i=0; i<MAX_LINKS; i++) {
-		if (s->link[i]!=NULL) exfree_link(s->link[i]);
+	for (i = 0; i < MAX_LINKS; i++) {
+		if (s->link[i] != NULL) exfree_link(s->link[i]);
 	}
 	xfree(s->link, MAX_LINKS*sizeof(Link));
+#ifdef USE_FAT_LINKAGES
 	xfree(s, sizeof(Sublinkage));
+#endif /* USE_FAT_LINKAGES */
 }
 
 #ifdef USE_FAT_LINKAGES
@@ -158,6 +169,7 @@ static void copy_full_link(Link **dest, Link *src)
 /* end new code 9/97 ALB */
 
 
+#ifdef USE_FAT_LINKAGES
 /**
  * Constructs a graph in the wordlinks array based on the contents of
  * the global link_array.  Makes the wordlinks array point to a list of
@@ -170,6 +182,7 @@ static void copy_full_link(Link **dest, Link *src)
 static void build_digraph(analyze_context_t *actx, Parse_info pi)
 {
 	int i, link;
+	Priority p;
 	Link *lp;
 	List_o_links * lol;
 
@@ -191,10 +204,10 @@ static void build_digraph(analyze_context_t *actx, Parse_info pi)
 		actx->word_links[lp->l] = lol;
 		lol->link = link;
 		lol->word = lp->r;
-		i = lp->lc->priority;
-		if (i == THIN_priority) {
+		p = lp->lc->priority;
+		if (p == THIN_priority) {
 			lol->dir = 0;
-		} else if (i == DOWN_priority) {
+		} else if (p == DOWN_priority) {
 			lol->dir = 1;
 		} else {
 			lol->dir = -1;
@@ -205,10 +218,10 @@ static void build_digraph(analyze_context_t *actx, Parse_info pi)
 		actx->word_links[lp->r] = lol;
 		lol->link = link;
 		lol->word = lp->l;
-		i = lp->rc->priority;
-		if (i == THIN_priority) {
+		p = lp->rc->priority;
+		if (p == THIN_priority) {
 			lol->dir = 0;
-		} else if (i == DOWN_priority) {
+		} else if (p == DOWN_priority) {
 			lol->dir = 1;
 		} else {
 			lol->dir = -1;
@@ -331,7 +344,6 @@ static DIS_node * build_DIS_node(analyze_context_t *actx,
 	return dn;
 }
 
-#ifdef USE_FAT_LINKAGES
 static void height_dfs(analyze_context_t *actx, int w, int height)
 {
 	List_o_links * lol;
@@ -433,7 +445,6 @@ static DIS_node * build_DIS_CON_tree(analyze_context_t *actx, Parse_info pi)
 	}
 	return dnroot;
 }
-#endif /* USE_FAT_LINKAGES */
 
 static int advance_CON(CON_node *);
 
@@ -597,7 +608,6 @@ static void free_CON_tree(CON_node * cn)
 	xfree((void *) cn, sizeof(CON_node));
 }
 
-#ifdef USE_FAT_LINKAGES
 /** scope out this and element */
 static void and_dfs_full(analyze_context_t *actx, int w)
 {
@@ -853,7 +863,7 @@ static void compute_pp_link_names(Sentence sent, Sublinkage *sublinkage)
 		 */
 		if (NULL == sublinkage->link[i]->lc) continue;
 		if (NULL == sublinkage->link[i]->rc) continue;
-		if (!x_match(sent, sublinkage->link[i]->lc, sublinkage->link[i]->rc))
+		if (!do_match(sent, sublinkage->link[i]->lc, sublinkage->link[i]->rc, 0, 0))
 		{
 			replace_link_name(sublinkage->link[i], pi->link_array[i].name);
 		}
@@ -951,7 +961,6 @@ Linkage_info analyze_fat_linkage(Sentence sent, Parse_Options opts, int analyze_
 		return li;
 	}
 
-#ifdef USE_FAT_LINKAGES
 	if (analyze_pass == PP_SECOND_PASS)
 	{
 	  li.andlist = build_andlist(actx, sent);
@@ -959,7 +968,6 @@ Linkage_info analyze_fat_linkage(Sentence sent, Parse_Options opts, int analyze_
 	  if (li.andlist) li.and_cost = li.andlist->cost;
 	}
 	else li.and_cost = 0;
-#endif /* USE_FAT_LINKAGES */
 
 	compute_link_names(sent);
 
@@ -1066,7 +1074,9 @@ Linkage_info analyze_thin_linkage(Sentence sent, Parse_Options opts, int analyze
 	Postprocessor * postprocessor;
 	Sublinkage *sublinkage;
 	Parse_info pi = sent->parse_info;
+#ifdef USE_FAT_LINKAGES
 	analyze_context_t *actx = sent->analyze_ctxt;
+#endif /* USE_FAT_LINKAGES */
 
 	sublinkage = x_create_sublinkage(pi);
 	postprocessor = sent->dict->postprocessor;
@@ -1085,7 +1095,9 @@ Linkage_info analyze_thin_linkage(Sentence sent, Parse_Options opts, int analyze
 		return li;
 	}
 
+#ifdef USE_FAT_LINKAGES
 	build_digraph(actx, pi);
+#endif /* USE_FAT_LINKAGES */
 
 	/* The code below can be used to generate the "islands" array.
 	 * For this to work, however, you have to call "build_digraph"
@@ -1095,12 +1107,13 @@ Linkage_info analyze_thin_linkage(Sentence sent, Parse_Options opts, int analyze
 
 	memset(&li, 0, sizeof(li));
 	li.N_violations = 0;
-	li.and_cost = 0;
 	li.unused_word_cost = unused_word_cost(sent->parse_info);
 #ifdef USE_FAT_LINKAGES
+	li.and_cost = 0;
 	li.improper_fat_linkage = FALSE;
-#endif /* USE_FAT_LINKAGES */
+	li.andlist = NULL;
 	li.inconsistent_domains = FALSE;
+#endif /* USE_FAT_LINKAGES */
 	if (opts->use_sat_solver)
 	{
 		li.disjunct_cost = 0.0;
@@ -1112,7 +1125,6 @@ Linkage_info analyze_thin_linkage(Sentence sent, Parse_Options opts, int analyze
 	li.null_cost = null_cost(pi);
 	li.link_cost = link_cost(pi);
 	li.corpus_cost = -1.0f;
-	li.andlist = NULL;
 
 	if (pp == NULL)
 	{
@@ -1124,7 +1136,11 @@ Linkage_info analyze_thin_linkage(Sentence sent, Parse_Options opts, int analyze
 	}
 
 	free_sublinkage(sublinkage);
+#ifdef USE_FAT_LINKAGES
 	free_digraph(actx, pi);
+#else
+	xfree(sublinkage, sizeof(Sublinkage));
+#endif /* USE_FAT_LINKAGES */
 	return li;
 }
 
@@ -1133,16 +1149,27 @@ void extract_thin_linkage(Sentence sent, Parse_Options opts, Linkage linkage)
 	int i;
 	Parse_info pi = sent->parse_info;
 
+#ifdef USE_FAT_LINKAGES
 	linkage->num_sublinkages = 1;
+	linkage->current = 0;
 	linkage->sublinkage = ex_create_sublinkage(pi);
+#else
+	ex_init_sublinkage(pi, &linkage->sublinkage);
+#endif /* USE_FAT_LINKAGES */
 
 	compute_link_names(sent);
 	for (i=0; i<pi->N_links; ++i)
 	{
+#ifdef USE_FAT_LINKAGES
 		linkage->sublinkage->link[i] = excopy_link(&(pi->link_array[i]));
+#else
+		linkage->sublinkage.link[i] = excopy_link(&(pi->link_array[i]));
+#endif /* USE_FAT_LINKAGES */
 	}
 }
 
+#ifdef USE_FAT_LINKAGES
+
 #ifdef DBG
 static void prt_lol(Sentence sent , List_o_links *lol)
 {
@@ -1206,7 +1233,6 @@ static void prt_dis_con_tree(Sentence sent, DIS_node *dis)
 static inline void prt_dis_con_tree(Sentence sent, DIS_node *dis) {}
 #endif
 
-#ifdef USE_FAT_LINKAGES
 /**
  * This procedure mimics analyze_fat_linkage in order to
  * extract the sublinkages and copy them to the Linkage
