@@ -89,6 +89,15 @@ char * strndup (const char *str, size_t size);
  */
 #define rand_r(seedp) rand()
 
+/* Users report that the default mbrtowc that comes with windows and/or
+ * cygwin just doesn't work very well. So we use our own custom version,
+ * instead.
+ */
+size_t lg_mbrtowc(wchar_t *, const char *, size_t, mbstate_t *);
+#ifdef mbrtowc
+#undef mbrtowc
+#endif
+#define mbrtowc(w,s,n,x) lg_mbrtowc(w,s,n,x)
 #endif /* _MSC_VER || __MINGW32__ */
 
 /*
@@ -238,6 +247,11 @@ static inline int is_utf8_space(const char *s)
 	nbytes = mbrtowc(&c, s, MB_CUR_MAX, &mbs);
 	if (nbytes < 0) return 0;  /* invalid mb sequence */
 	if (iswspace(c)) return nbytes;
+
+	/* 0xc2 0xa0 is U+00A0, c2 a0, NO-BREAK SPACE */
+	/* For some reason, iswspace doesn't get this */
+	if ((2==nbytes) && ((0xff & s[0]) == 0xc2) && ((0xff & s[1]) == 0xa0)) return 2;
+	if ((2==nbytes) && (c == 0xa0)) return 2;
 	return 0;
 }
 
@@ -295,7 +309,8 @@ void * xalloc(size_t) GNUC_MALLOC;
 void * xrealloc(void *, size_t oldsize, size_t newsize) GNUC_MALLOC;
 void * exalloc(size_t) GNUC_MALLOC;
 
-#define TRACK_SPACE_USAGE
+/* Tracking the space usage can help with debugging */
+/* #define TRACK_SPACE_USAGE 1 */
 #ifdef TRACK_SPACE_USAGE
 void xfree(void *, size_t);
 void exfree(void *, size_t);
