@@ -17,7 +17,8 @@
 #include <math.h>
 #include <stdio.h>
 
-#include "api.h"
+#include "count.h"
+#include "dict-api.h"
 #include "disjunct-utils.h"
 #include "word-utils.h"
 
